# Explanations

Explanations of how it works and why it works that way.

```{toctree}
:maxdepth: 1
:glob:
explanations/architecture-overview.md
explanations/fastcs-epics-ioc.md
explanations/ads-client.md
explanations/api-decoupling.md

explanations/*
```
